@@ -51,7 +51,7 @@ void allocateKnownWidths(SEXP layout,
 			 int *relativeWidths, 
 			 double parentWidthCM, double parentHeightCM,
 			 LViewportContext parentContext,
-			 DevDesc *dd,
+			 GEDevDesc *dd,
 			 double *npcWidths, double *widthLeftCM) 
 {
     int i;
@@ -59,6 +59,8 @@ void allocateKnownWidths(SEXP layout,
     for (i=0; i<layoutNCol(layout); i++) 
 	if (!relativeWidths[i]) {
 	    npcWidths[i] = transformWidth(widths, i, parentContext,
+					  parentContext.fontfamily,
+					  parentContext.font,
 					  parentContext.fontsize,
 					  parentContext.lineheight,
 					  parentWidthCM, parentHeightCM, dd);
@@ -70,7 +72,7 @@ void allocateKnownHeights(SEXP layout,
 			  int *relativeHeights,
 			  double parentWidthCM, double parentHeightCM,
 			  LViewportContext parentContext,
-			  DevDesc *dd,
+			  GEDevDesc *dd,
 			  double *npcHeights, double *heightLeftCM) 
 {
     int i;
@@ -78,6 +80,8 @@ void allocateKnownHeights(SEXP layout,
     for (i=0; i<layoutNRow(layout); i++) 
 	if (!relativeHeights[i]) {
 	    npcHeights[i] = transformHeight(heights, i, parentContext,
+					    parentContext.fontfamily,
+					    parentContext.font,
 					    parentContext.fontsize,
 					    parentContext.lineheight,
 					    parentWidthCM, parentHeightCM, dd);
@@ -94,7 +98,7 @@ int colRespected(int col, SEXP layout) {
 	result = 1;
     else
 	for (i=0; i<layoutNRow(layout); i++)
-	    if (respectMat[i*layoutNCol(layout) + col] != 0)
+	    if (respectMat[col*layoutNRow(layout) + i] != 0)
 		result = 1;
     return result;
 }
@@ -108,7 +112,7 @@ int rowRespected(int row, SEXP layout) {
 	result = 1;
     else
 	for (i=0; i<layoutNCol(layout); i++)
-	    if (respectMat[row*layoutNCol(layout) + i] != 0)
+	    if (respectMat[i*layoutNRow(layout) + row] != 0)
 		result = 1;
     return result;
 }
@@ -126,6 +130,8 @@ double totalWidth(SEXP layout, int *relativeWidths,
     for (i=0; i<layoutNCol(layout); i++) 
 	if (relativeWidths[i])
 	    totalWidth += transformWidth(widths, i, parentContext, 
+					 parentContext.fontfamily,
+					 parentContext.font,
 					 parentContext.fontsize,
 					 parentContext.lineheight,
 					 0, 0, NULL);
@@ -144,6 +150,8 @@ double totalHeight(SEXP layout, int *relativeHeights,
     for (i=0; i<layoutNRow(layout); i++) 
 	if (relativeHeights[i])
 	    totalHeight += transformHeight(heights, i, parentContext, 
+					   parentContext.fontfamily,
+					   parentContext.font,
 					   parentContext.fontsize,
 					   parentContext.lineheight,
 					   0, 0, NULL);
@@ -156,7 +164,7 @@ void allocateRespected(SEXP layout,
 		       double hmult, double vmult,
 		       double *reducedWidthCM, double *reducedHeightCM,
 		       LViewportContext parentContext,
-		       DevDesc *dd,
+		       GEDevDesc *dd,
 		       double *npcWidths, double *npcHeights)
 {
     int i;
@@ -188,9 +196,11 @@ void allocateRespected(SEXP layout,
 		    /* Build a unit SEXP with a single value and no data
 		     */
 		    SEXP width;
-		    PROTECT(width = unit(unitValue(widths, i)/denom*mult, 
-					 L_CM));
+		    PROTECT(width = unit(pureNullUnitValue(widths, i) / 
+					 denom*mult, L_CM));
 		    npcWidths[i] = transformWidth(width, 0, parentContext,
+						  parentContext.fontfamily,
+						  parentContext.font,
 						  parentContext.fontsize,
 						  parentContext.lineheight,
 						  tempWidthCM, 
@@ -206,9 +216,11 @@ void allocateRespected(SEXP layout,
 	    if (relativeHeights[i])
 		if (rowRespected(i, layout)) {
 		    SEXP height;
-		    PROTECT(height = unit(unitValue(heights, i)/denom*mult,
-					  L_CM));
+		    PROTECT(height = unit(pureNullUnitValue(heights, i) / 
+					  denom*mult, L_CM));
 		    npcHeights[i] = transformHeight(height, 0, parentContext,
+						    parentContext.fontfamily,
+						    parentContext.font,
 						    parentContext.fontsize,
 						    parentContext.lineheight,
 						    tempWidthCM, 
@@ -235,6 +247,8 @@ double totalUnrespectedWidth(SEXP layout, int *relativeWidths,
 	if (relativeWidths[i])
 	    if (!colRespected(i, layout))
 		totalWidth += transformWidth(widths, i, parentContext, 
+					     parentContext.fontfamily,
+					     parentContext.font,
 					     parentContext.fontsize,
 					     parentContext.lineheight,
 					     0, 0, NULL);
@@ -254,6 +268,8 @@ double totalUnrespectedHeight(SEXP layout, int *relativeHeights,
 	if (relativeHeights[i])
 	    if (!rowRespected(i, layout))
 		totalHeight += transformHeight(heights, i, parentContext, 
+					       parentContext.fontfamily,
+					       parentContext.font,
 					       parentContext.fontsize,
 					       parentContext.lineheight,
 					       0, 0, NULL);
@@ -276,6 +292,8 @@ void allocateRemainingWidth(SEXP layout, int *relativeWidths,
 	    if (!colRespected(i, layout))
 		npcWidths[i] = multiplier*
 		    transformWidth(widths, i, parentContext, 
+				   parentContext.fontfamily,
+				   parentContext.font,
 				   parentContext.fontsize,
 				   parentContext.lineheight,
 				   0, 0, NULL)/
@@ -299,6 +317,8 @@ void allocateRemainingHeight(SEXP layout, int *relativeHeights,
 	    if (!rowRespected(i, layout))
 		npcHeights[i] = multiplier*
 		    transformHeight(heights, i, parentContext, 
+				    parentContext.fontfamily,
+				    parentContext.font,
 				    parentContext.fontsize,
 				    parentContext.lineheight,
 				    0, 0, NULL)/
@@ -334,7 +354,7 @@ void calcViewportLayout(SEXP viewport,
 			double parentWidthCM,
 			double parentHeightCM,
 			LViewportContext parentContext,
-			DevDesc *dd)
+			GEDevDesc *dd)
 {
     int i;
     SEXP currentWidths, currentHeights;
